@@ -4,26 +4,26 @@
 		adSim <- function(x, distribution = "normal", b = 10000){
 	
 	
-# Fehlerprüfungen durchführen
+# Fehlerpruefungen durchfuehren
 
-# 1.20 Überprüfung, dass x ein numerischer Vektor ist
+# 1.20 ueberpruefung, dass x ein numerischer Vektor ist
 		if(mode(x) != "numeric")
 			stop(paste("\n","          adSim() requires numeric x data"))	
 			
-# 1.25 Überprüfung von x auf fehlende Werte
+# 1.25 ueberpruefung von x auf fehlende Werte
 		if(any(is.na(x))) 
 			stop(paste("\n","          x data has missing values (NA)"))
 	
-# 1.30 Überprüfung, ob auf die angegebene Verteilung getestet werden kann
+# 1.30 ueberpruefung, ob auf die angegebene Verteilung getestet werden kann
 		
-			# Vektor "distr" enthält die testbaren Verteilungsmodelle
+			# Vektor "distr" enthaelt die testbaren Verteilungsmodelle
 			distr <- c("exponential","cauchy","gumbel","gamma","log-normal","lognormal","logistic","normal","weibull")
 			
 			if(any(distr == distribution)  == FALSE)
 				stop(paste("\n","          adSim() can not apply for",distribution,"distribution.				Please choose one of the following distributions for testing goodness-of-fit:				exponential, cauchy, gumbel, gamma, log-normal, lognormal, logistic, normal, weibull"))
 
 
-# 1.35 & 1.40 Überprüfung, ob die gewählte Verteilung für Werte von x<=0 definiert ist bzw. der MLE berechnet werden kann, wenn x entsprechende Werte hat
+# 1.35 & 1.40 ueberpruefung, ob die gewaehlte Verteilung fuer Werte von x<=0 definiert ist bzw. der MLE berechnet werden kann, wenn x entsprechende Werte hat
 			
 			if(any(x<=0)){
 				if(distribution == "exponential" || distribution == "lognormal" || distribution == "log-normal" || distribution == "gamma" || distribution == "weibull"){ 
@@ -31,15 +31,15 @@
 				 	
 				
 
-# 1.45 & 1.50: bei log-Normalverteilung wird die Stichprobe logarithmiert und anschließend auf Normalverteilung getestet
+# 1.45 & 1.50: bei log-Normalverteilung wird die Stichprobe logarithmiert und anschliessend auf Normalverteilung getestet
 # 1.52 "testDistr" gibt die Verteilung an, auf die im Funktionsablauf getestet werden soll (nicht immer identisch mit der hypothetischen Verteilung des Anwenders)
 	
 		if(distribution == "lognormal" || distribution == "log-normal"){
 				x <- log(x)
 				testDistr <- "normal"    				}
 
-# 1.54 & 1.56 & 1.58: bei Weibull-Verteilung wird die Stichprobe tranformiert x=-log(x) und anschließend auf Gumbel-Verteilung getestet
-# obwohl die Weibull-Verteilung für x>=0 definiert ist, muss aufgrund der Logarithmierung x>0 gelten (die Prüfung erfolgt bereits mit 1.35 & 1.40)
+# 1.54 & 1.56 & 1.58: bei Weibull-Verteilung wird die Stichprobe tranformiert x=-log(x) und anschliessend auf Gumbel-Verteilung getestet
+# obwohl die Weibull-Verteilung fuer x>=0 definiert ist, muss aufgrund der Logarithmierung x>0 gelten (die Pruefung erfolgt bereits mit 1.35 & 1.40)
 
 	if(distribution == "weibull"){
 				x <- -log(x)
@@ -54,7 +54,7 @@
 	
 		n = length(x)
 		
-# 1.80 Prüfung auf eine Mindeststichprobengröße
+# 1.80 Pruefung auf eine Mindeststichprobengroesse
 	
 		if(n<3)
 			stop(paste("\n","          adSim() can not apply for sample sizes n < 3."))
@@ -65,21 +65,22 @@
 
 
 ###################################################################
-# 2.00 Parameterschätzung
+# 2.00 Parameterschaetzung
 ###################################################################
 
 
-# 2.10 & 2.15 Zum Schätzen der Parameter standardmäßig den MLE benutzen (außer für die Normal-, Cauchy- und Gumbel-Verteilung)
-# Parameter der Verteilung aus Stichprobe schätzen und als Liste "parafit" speichern
+# 2.10 & 2.15 Zum Schaetzen der Parameter standardmaessig den MLE benutzen (ausser fuer die Normal-, Cauchy- und Gumbel-Verteilung)
+# Parameter der Verteilung aus Stichprobe schaetzen und als Liste "parafit" speichern
 	
 	if(testDistr != "normal" & testDistr != "gumbel" & testDistr != "cauchy"){
-			library(MASS)
-			parafit <- fitdistr(x,testDistr)
+			#library(MASS)
+	  
+			parafit <- MASS::fitdistr(x,testDistr)
 			}
 
-# 2.30 & 2.35 Schätzen der Parameter der Normalverteilung 
-# der MLE ist für die Standardabweichung der Normalverteilung nicht erwartungstreu
-# Parameter der Normalverteilung werden mit mean() und sd()  geschätzt und als Vektor "parafit" gespeichert	
+# 2.30 & 2.35 Schaetzen der Parameter der Normalverteilung 
+# der MLE ist fuer die Standardabweichung der Normalverteilung nicht erwartungstreu
+# Parameter der Normalverteilung werden mit mean() und sd()  geschaetzt und als Vektor "parafit" gespeichert	
 
 	if(testDistr == "normal"){
 				parafit 	<- numeric(2)
@@ -92,34 +93,34 @@
     			}else{names(parafit) = c(  "mean",  "sd")}		# 2.42
 			}
 	
-# 2.50 Schätzen der Cauchy-Parameter
-# Für die Cauchy-Verteilung sind zwei unterschiedliche Schätzverfahren implementiert
+# 2.50 Schaetzen der Cauchy-Parameter
+# Fuer die Cauchy-Verteilung sind zwei unterschiedliche Schaetzverfahren implementiert
 
 	if(testDistr == "cauchy"){
 
-		# 2.52 Prüfung, ob simuliert wird oder kritische Werte ausgelesen werden sollen	
+		# 2.52 Pruefung, ob simuliert wird oder kritische Werte ausgelesen werden sollen	
 		
-		if(is.na(b) == FALSE){		# die AD-Verteilung soll später simuliert werden
+		if(is.na(b) == FALSE){		# die AD-Verteilung soll spaeter simuliert werden
 			
-			# 2.55 Schätzung mittels fitdistr()	
+			# 2.55 Schaetzung mittels fitdistr()	
 				
-				library(MASS)
-				parafit <- fitdistr(x,testDistr)
+				#library(MASS)
+				parafit <- MASS::fitdistr(x,testDistr)
 				
-		}else{						# 2.52 die AD-Verteilung soll später nicht simuliert werden			
+		}else{						# 2.52 die AD-Verteilung soll spaeter nicht simuliert werden			
 			
-		# 2.60 Parameterschätzung, basierend auf den Summen der gewichteten Ordnungsstatistik
+		# 2.60 Parameterschaetzung, basierend auf den Summen der gewichteten Ordnungsstatistik
 						
 			parafit 	<- numeric(2)
 		
 			uWeight = numeric(n)
 			uWeight[1:n] <- sin( 4*pi* ( 1:n/(n+1) - 0.5)  ) / (n*tan( pi* ( 1:n/(n+1) - 0.5 )  ) )  # Berechnung der Gewichte u
 		
-			#  für ungerade n können nicht alle Gewichte berechnet werden, deshalb wird das fehlende Gewicht geschätzt
+			#  fuer ungerade n koennen nicht alle Gewichte berechnet werden, deshalb wird das fehlende Gewicht geschaetzt
 			if(ifelse(n %% 2, TRUE, FALSE)){ 	# ifelse-Bedingung gibt TRUE, wenn n ungerade ist
-				if(length(na.omit(uWeight)) + 1 == length(uWeight)){  # Bedingung prüft, ob nur ein Wert in uWeight nicht berechnet werden konnte
+				if(length(na.omit(uWeight)) + 1 == length(uWeight)){  # Bedingung prueft, ob nur ein Wert in uWeight nicht berechnet werden konnte
 				
-				 uWeight[which(is.na(uWeight))] = (n+1)/n - sum(na.omit(uWeight))   # Ersetzen von NaN durch geeigneten Schätzer 
+				 uWeight[which(is.na(uWeight))] = (n+1)/n - sum(na.omit(uWeight))   # Ersetzen von NaN durch geeigneten Schaetzer 
 				}}				
 			parafit[1] 	<- uWeight %*% x 			# Parameterberechnung
 
@@ -135,18 +136,18 @@
 			}
 	
 
-# 2.70 Schätzen der Gumbel-Parameter (fitdistr() kann nicht die Gumbel-Verteilung schätzen)
+# 2.70 Schaetzen der Gumbel-Parameter (fitdistr() kann nicht die Gumbel-Verteilung schaetzen)
 
 	if(testDistr == "gumbel"){
 		
-				### 2.72 p-Gumbel-Funktion definieren (aus Library VGAM übernommen)
+				### 2.72 p-Gumbel-Funktion definieren (aus Library VGAM uebernommen)
 						
 					pgumbel = function (q, location = 0, scale = 1){
     								answer = exp(-exp(-(q - location)/scale))
    									answer[scale <= 0] = NaN
     								answer}
 				
-				### 2.75 r-Gumbel-Funktion definieren (aus Library VGAM übernommen)
+				### 2.75 r-Gumbel-Funktion definieren (aus Library VGAM uebernommen)
 					
 					is.Numeric = function (x, allowable.length = Inf, integer.valued = FALSE, positive = FALSE){
 									if (all(is.numeric(x)) && all(is.finite(x)) && (if (is.finite(allowable.length)) length(x) == 
@@ -164,11 +165,11 @@
     								answer}
 			
 				
-				### 2.80 MLE-Parameterschätzung für die Gumbel-Verteilung (iterative Lösung)
+				### 2.80 MLE-Parameterschaetzung fuer die Gumbel-Verteilung (iterative Loesung)
 			
 				f <- function(p) 1/n*sum(x) - (sum(x*exp(-x/p)))/(sum(exp(-x/p)))-p
 					
-					### iterative Lösung notwendig, um beta zu schätzen (D'Agostino/Stephens 1986, S. 146)
+					### iterative Loesung notwendig, um beta zu schaetzen (D'Agostino/Stephens 1986, S. 146)
 				
 					itSol <- uniroot(f,c(-100,100),tol = 0.0000001, maxiter = 100000)
 					beta <- as.numeric(itSol$root)
@@ -222,20 +223,20 @@
  			
  	# 3.50 Anwendung der AD-Formel
 
-			# 3.60 für jedes i den Summenwert berechnen und in Matrix h schreiben
+			# 3.60 fuer jedes i den Summenwert berechnen und in Matrix h schreiben
 			h = matrix(ncol=n)
 
 			h[1,] = (2*col(h)-1)*log(pit) + (2*n + 1 - 2*col(h))* log(1 - pit) 
 			
-			# 3.70 AD-Formel vollständig berechnen
+			# 3.70 AD-Formel vollstaendig berechnen
 			AD = -n-(1/n) * rowSums(h)
 		
 
-			# 3.80 Fehlerprüfung, ob AD-Wert vorhanden ist
+			# 3.80 Fehlerpruefung, ob AD-Wert vorhanden ist
 			if(is.na(AD) == TRUE || AD<0)
 				stop(paste("\n","        The calculation of the Anderson Darling statistic fails."))
 	
-			# Ende der AD-Wert-Berechnung für die beobachteten Daten
+			# Ende der AD-Wert-Berechnung fuer die beobachteten Daten
 			
 if(is.na(b) == FALSE){
 
@@ -244,7 +245,7 @@ if(is.na(b) == FALSE){
 #       4 parametrisches Bootstrapping der AD-Nullverteilung
 #####################################################################################
 	
-	# 4.00 Fehlerprüfung, ob die Simulationshäufigkeit zulässig gewählt ist
+	# 4.00 Fehlerpruefung, ob die Simulationshaeufigkeit zulaessig gewaehlt ist
 	
 		if(b<1000)
 			stop("b is chosen too small for generate an accurate p-Value.")
@@ -255,9 +256,9 @@ if(is.na(b) == FALSE){
 		cat("\n","   ... simulating the Anderson-Darling distribution by",b,"bootstraps for",distribution,"distribution...","\n","\n")
 
 
-	# 4.05 Resampling und Parameterschätzung
+	# 4.05 Resampling und Parameterschaetzung
 	# Matrix Y mit b sortierten Zufallsstichproben mit Umfang n erstellen
-	# Verteilungsparameter zu jeder Bootstrap-Stichprobe schätzen	
+	# Verteilungsparameter zu jeder Bootstrap-Stichprobe schaetzen	
 	
 								
 			# 4.10
@@ -302,7 +303,7 @@ if(is.na(b) == FALSE){
  					
  				for(j in 1:b){
  					 					
-					### iterative Lösung notwendig, um beta zu schätzen (D'Agostino/Stephens 1986, S. 146)
+					### iterative Loesung notwendig, um beta zu schaetzen (D'Agostino/Stephens 1986, S. 146)
 				
 					itSol <- uniroot(function(p) 1/n*sum(Y[j,])-
 									(sum(Y[j,]*exp(-Y[j,]/p)))/(sum(exp(-Y[j,]/p)))-p,c(-100,100),tol = 0.0000000001, maxiter = 100000)
@@ -325,8 +326,8 @@ if(is.na(b) == FALSE){
 ### 4.40 b-fache Berechnung der Anderson-Darling-Formel
 ######################################################################
 
-# PIT für jeden Wert der Matrix Y berechnen
-# (abhängig von den geschätzten Verteilungsparameter jeder Bootstrap-Stichprobe)
+# PIT fuer jeden Wert der Matrix Y berechnen
+# (abhaengig von den geschaetzten Verteilungsparameter jeder Bootstrap-Stichprobe)
 
 			#4.45
 			if(testDistr == "normal")
@@ -352,7 +353,7 @@ if(is.na(b) == FALSE){
 					Y[,1:n] <- plogis(Y[,1:n],paraLocation,paraScale)
 
 
-# 4.75 Berechnung der Summenglieder der AD-(Lewis)-Formel zu jeder Bootstrap-Stichprobe (Matrix Y überschreiben)
+# 4.75 Berechnung der Summenglieder der AD-(Lewis)-Formel zu jeder Bootstrap-Stichprobe (Matrix Y ueberschreiben)
 
 Y[1:b,] <- (2*col(Y)-1)*log(Y[1:b,]) +  (2*n + 1 - 2*col(Y)) * log(1 - Y[1:b,])
  	
@@ -364,7 +365,7 @@ Y[1:b,] <- (2*col(Y)-1)*log(Y[1:b,]) +  (2*n + 1 - 2*col(Y)) * log(1 - Y[1:b,])
 
 	simAD[1:b] = -n-(1/n)*d[1:b]
 
-# 4.80 Fehlerprüfung, ob alle AD-Werte bestimmt werden konnten
+# 4.80 Fehlerpruefung, ob alle AD-Werte bestimmt werden konnten
 if(any(is.na(simAD))){
 	cat("    The simulated Anderson-Darling distribution contains NAs or NaNs!","\n","\n")}
 		
@@ -388,7 +389,7 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 	
 		# 5.00 (b = NA), d.h. Auslesen tabellierter kritischer Werte bzw. des p-Werts oder Anwendung von Berechnungsformeln zur p-Wert-Bestimmung
 		
-		# 5.02 simAD wird später in der Ausgabe abgerufen, weshalb die Variable definiert sein muss
+		# 5.02 simAD wird spaeter in der Ausgabe abgerufen, weshalb die Variable definiert sein muss
 		simAD = NA
 		
 		### 5.06 Definieren einer Matrix "critValues" zur Erfassung kritischer Werte
@@ -403,19 +404,19 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 				if(testDistr == "normal"){
 						
 					###################################################################################################################
-					### kritische Werte für die Normalverteilung nach D'Agostino und Stephens 1986 - S. 123   Tab. 4.7 
+					### kritische Werte fuer die Normalverteilung nach D'Agostino und Stephens 1986 - S. 123   Tab. 4.7 
 					################################################################################################################### 					
 					
 					# 5.12 Tabelle der kritischen Werte
 					normalMtx = matrix(c(	0.50 , 0.75, 0.85 , 0.90 , 0.95 , 0.975 , 0.99 , 0.995 , 
 											0.341 , 0.470 , 0.561 , 0.631 , 0.752 , 0.873 , 1.035 , 1.159), nrow=2, byrow = TRUE )
 					
-					# 5.14 Anpassen der Wertetabelle bezüglich des Stichprobenumfangs
+					# 5.14 Anpassen der Wertetabelle bezueglich des Stichprobenumfangs
 					normalMtx[2,1:ncol(normalMtx)] = normalMtx[2,1:ncol(normalMtx)]/(1+0.75/n+2.25/n^2)
 					refMtx = normalMtx
 					
 					########################################################################################################
-					### p-Wert Berechnung für die Normalverteilung nach D'Agostino und Stephens 1986 - S. 127    
+					### p-Wert Berechnung fuer die Normalverteilung nach D'Agostino und Stephens 1986 - S. 127    
 					######################################################################################################## 
 					
 					# 5.16 Anpassen des AD-Werts bzgl. des Stichprobenumfangs
@@ -436,20 +437,20 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 				if(testDistr == "exponential"){
 					
 					#############################################################################################################
-					### Kritische Werte für die Exponentialverteilung nach D'Agostino und Stephens 1986 - S. 135   Tab. 4.11   
+					### Kritische Werte fuer die Exponentialverteilung nach D'Agostino und Stephens 1986 - S. 135   Tab. 4.11   
 					############################################################################################################# 					
 					
 					# 5.22 Tabelle der kritischen Werte
 						expMtx = matrix( c( 0.75, 0.80, 0.85 , 0.90 , 0.95 , 0.975 , 0.99 , 0.995 , 0.9975,
 										0.736 , 0.816 , 0.916 , 1.062 , 1.321 , 1.591 , 1.959 , 2.244, 2.534), nrow = 2, byrow = TRUE )
 					
-					# 5.24 Anpassen der Wertetabelle bezüglich des Stichprobenumfangs
+					# 5.24 Anpassen der Wertetabelle bezueglich des Stichprobenumfangs
 						expMtx[2,1:ncol(expMtx)] = expMtx[2,1:ncol(expMtx)]/(1+0.6/n)
 	
 						refMtx = expMtx
 				
 					############################################################################################################
-					### p-Wert-Berechnung für die Exponentialverteilung nach D'Agostino und Stephens 1986 - S. 136
+					### p-Wert-Berechnung fuer die Exponentialverteilung nach D'Agostino und Stephens 1986 - S. 136
 					### Case 2: origin (bzw. location) = 0 = known , scale = unknown = 1/Lambda = 1/rate  
 					############################################################################################################
 					
@@ -474,14 +475,14 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 				if(testDistr == "gumbel"){
 					
 					##############################################################################################################
-					### Kritische Werte für die Extremwert-Verteilung nach D'Agostino und Stephens 1986 - S. 146   Tab. 4.17   
+					### Kritische Werte fuer die Extremwert-Verteilung nach D'Agostino und Stephens 1986 - S. 146   Tab. 4.17   
 					############################################################################################################## 					
 					
 					# 5.32 Tabelle der kritischen Werte
 						gumbelMtx = matrix(c( 0.75, 0.90 , 0.95 , 0.975 , 0.99 , 0.474, 0.637, 0.757, 0.877, 1.038), nrow = 2, byrow = TRUE )
 					
 											
-					# 5.34 Anpassen der Wertetabelle bezüglich des Stichprobenumfangs
+					# 5.34 Anpassen der Wertetabelle bezueglich des Stichprobenumfangs
 						gumbelMtx[2,1:ncol(gumbelMtx)] = gumbelMtx[2,1:ncol(gumbelMtx)]/(1 + 0.2/sqrt(n))
 						refMtx = gumbelMtx
 				}
@@ -490,25 +491,25 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 				if(testDistr == "logistic"){
 						
 					##############################################################################################################
-					### kritische Werte für die logistische Verteilung nach D'Agostino und Stephens 1986 - S. 157   Tab 4.22 
+					### kritische Werte fuer die logistische Verteilung nach D'Agostino und Stephens 1986 - S. 157   Tab 4.22 
 					############################################################################################################## 
 										
 					# 5.37 Tabelle der kritischen Werte
 						logisMtx = matrix(c( 0.75, 0.90 , 0.95 , 0.975 , 0.99 , 0.995 , 0.426, 0.563, 0.660, 0.769, 0.906, 1.010 ), nrow = 2, byrow = TRUE )
 					
-					# 5.39 Anpassen der Wertetabelle bezüglich des Stichprobenumfangs
+					# 5.39 Anpassen der Wertetabelle bezueglich des Stichprobenumfangs
 						logisMtx[2,1:ncol(logisMtx)] = logisMtx[2,1:ncol(logisMtx)]/(1 + 0.25/n)
 						refMtx = logisMtx
 		}
 			
 						
 				##############################################################################################################
-				### Bestimmung des p-Werts für die Gumbel- oder logistische Verteilung
+				### Bestimmung des p-Werts fuer die Gumbel- oder logistische Verteilung
 				############################################################################################################## 
 			
-					critCheck <- refMtx[2,1:ncol(refMtx)] > AD   ### gibt TRUE aus für alle Einträge in der Zeile, die größer als AD sind
+					critCheck <- refMtx[2,1:ncol(refMtx)] > AD   ### gibt TRUE aus fuer alle Eintraege in der Zeile, die groesser als AD sind
 					
-						# 5.40 Existiert ein kritischer Wert, der größer als der AD-Wert ist?   	
+						# 5.40 Existiert ein kritischer Wert, der groesser als der AD-Wert ist?   	
 						if(any(critCheck)){
 							
 							
@@ -516,7 +517,7 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 								firPos <- min(which(critCheck)) - 1
 
 						}else{
-							# 5.44 letzte Spalte als Position wählen
+							# 5.44 letzte Spalte als Position waehlen
 								firPos <- ncol(refMtx)}
 							
 							# 5.46 p-Wert entsprechend der ermittelten Position bestimmen
@@ -528,20 +529,20 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 									pValue <- paste("<=",pValue)}}
 										
 				##############################################################################################################
-				### Auslesen der kritischen Werte für Normal-, Exponential-, Gumbel oder logistische Verteilung				
+				### Auslesen der kritischen Werte fuer Normal-, Exponential-, Gumbel oder logistische Verteilung				
 				############################################################################################################## 
 												
 					for(i in 1:ncol(critValues)){
 						
-						# 5.50 Ist der kritische Werte für das zu spezifizierende Quantil tabelliert?
+						# 5.50 Ist der kritische Werte fuer das zu spezifizierende Quantil tabelliert?
 						if(any(refMtx[1,1:ncol(refMtx)] == critValues[1,i])){                          
 							
 								
 							# 5.52 dann Position des kritischen Werts bzgl. des betrachteten Quantils erfassen
 								position <- (1:length(refMtx[1,1:ncol(refMtx)] == critValues[1,i]))[(refMtx[1,1:ncol(refMtx)] == critValues[1,i])] 
 							
-							# 5.54 Auslesen des kritischen Werts bezüglich der Position	
-								critValues[2,i] <- refMtx[2,position]          ### liest aus der Matrix den kritschen Wert abhängig vom gewählten Quantil
+							# 5.54 Auslesen des kritischen Werts bezueglich der Position	
+								critValues[2,i] <- refMtx[2,position]          ### liest aus der Matrix den kritschen Wert abhaengig vom gewaehlten Quantil
 						}else{
 							# 5.58 nicht-tabellierte Quantile mit "NA" belegen
 								critValues[2,i] <- NA}}
@@ -551,7 +552,7 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 	if(testDistr == "gamma"){
 					
 					###################################################################################################################################
-					### Bestimmung des kritischen Werts und des p-Werts für die Gammaverteilung nach D'Agostino und Stephens 1986 - S. 155 - Tab. 4.21
+					### Bestimmung des kritischen Werts und des p-Werts fuer die Gammaverteilung nach D'Agostino und Stephens 1986 - S. 155 - Tab. 4.21
 					### case 3: shape = unknown, scale = unknown = 1/rate, origin = known = 0    
 					###################################################################################################################################
 					
@@ -568,25 +569,25 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 
 							
 					###################################################################################################################################
-					######## p-Wert-Bestimmung für die Gamma-Verteilung
+					######## p-Wert-Bestimmung fuer die Gamma-Verteilung
 					###################################################################################################################################
 					
-						# critCheck gibt TRUE aus für alle Einträge in der entsprechenden m-Zeile, die größer als der AD-Wert sind
+						# critCheck gibt TRUE aus fuer alle Eintraege in der entsprechenden m-Zeile, die groesser als der AD-Wert sind
 						# zu beachten ist, dass die Betrachtung erst ab der 2ten Spalte der Tabelle erfolgt, so dass die Indizierung von critCheck
-						# gegenüber der Indizierung der Tabelle  um -1 verschoben ist 
+						# gegenueber der Indizierung der Tabelle  um -1 verschoben ist 
 						
 							critCheck <- gammaDF[min(which(gammaDF$m >= parafit$estimate["shape"])),2:ncol(gammaDF)] > AD   
 								 
-						# 5.65 Existiert ein kritischer Wert, der größer als der AD-Wert ist (in der entsprechenden m-Zeile)?  
+						# 5.65 Existiert ein kritischer Wert, der groesser als der AD-Wert ist (in der entsprechenden m-Zeile)?  
 							if(any(critCheck)){	
 								
 								# 5.66 firPos gibt die Spalten-Position der Tabelle in der entsprechenden m-Zeile von dem krit. Wert an, 
-								# der noch kleiner als der AD-Wert ist. Für firPos = 1 existiert kein kleiner kritischer Wert
+								# der noch kleiner als der AD-Wert ist. Fuer firPos = 1 existiert kein kleiner kritischer Wert
 								
 									firPos <- min(which(critCheck))     
 							}else{
 								
-							# 5.67 letzte Spalte als Position wählen
+							# 5.67 letzte Spalte als Position waehlen
 									firPos <- ncol(gammaDF) }
 							
 							# 5.68  p-Wert entsprechend der ermittelten Position bestimmen	
@@ -598,13 +599,13 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 									pValue <- paste("<=",pValue)}
 
 					###################################################################################################################################
-					######## kritischen Wert für die Gamma-Verteilung auslesen
+					######## kritischen Wert fuer die Gamma-Verteilung auslesen
 					###################################################################################################################################
 						  
 							
 							for(i in 1:ncol(critValues)){
 								
-								# 5.70 Ist der kritische Wert für das zu spezifizierende Quantil tabelliert?
+								# 5.70 Ist der kritische Wert fuer das zu spezifizierende Quantil tabelliert?
 								if(any(names(gammaDF) == critValues[1,i] )){
 									
 									
@@ -620,7 +621,7 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 	if(testDistr == "cauchy"){
 					
 					####################################################################################################################
-					### Bestimmung des kritischen Werts für die Cauchy-Verteilung nach D'Agostino und Stephens 1986 - S. 163   Tab 4.26
+					### Bestimmung des kritischen Werts fuer die Cauchy-Verteilung nach D'Agostino und Stephens 1986 - S. 163   Tab 4.26
 					### case 3: location = unknown, shape = unknown        
 					#################################################################################################################### 					
 					
@@ -638,26 +639,26 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 
 								
 					##############################################################################################################
-					### Bestimmung des p-Werts für die Cauchy-Verteilung 
+					### Bestimmung des p-Werts fuer die Cauchy-Verteilung 
 					############################################################################################################## 
 				
-					# 5.84 Existieren kritische Werte für den zu untersuchenden Stichprobenumfang n?
+					# 5.84 Existieren kritische Werte fuer den zu untersuchenden Stichprobenumfang n?
 					if(any(cauchyDF[1:13,1] == n)){						
 					
-						# critCheck gibt TRUE aus für alle Einträge in der entsprechenden n-Zeile, die größer als der AD-Wert sind
+						# critCheck gibt TRUE aus fuer alle Eintraege in der entsprechenden n-Zeile, die groesser als der AD-Wert sind
 						# zu beachten ist, dass die Betrachtung erst ab der 2ten Spalte der Tabelle erfolgt, so dass die Indizierung von critCheck
-						# gegenüber der Indizierung der Tabelle um -1 verschoben ist				
+						# gegenueber der Indizierung der Tabelle um -1 verschoben ist				
 								critCheck <- cauchyDF[which(cauchyDF[1:13,1] == n),2:ncol(cauchyDF)] > AD
 						
-						# 5.85 Existiert ein kritischer Wert, der größer als der AD-Wert ist (in der entsprechenden n-Zeile)? 
+						# 5.85 Existiert ein kritischer Wert, der groesser als der AD-Wert ist (in der entsprechenden n-Zeile)? 
 							if(any(critCheck)){	
 									
 								# 5.86 firPos gibt die Spalten-Position der Tabelle in der entsprechenden n-Zeile von dem krit. Wert an, 
-								# der noch kleiner als der AD-Wert ist; für firPos = 1 existiert kein kleiner kritischer Wert
+								# der noch kleiner als der AD-Wert ist; fuer firPos = 1 existiert kein kleiner kritischer Wert
 									firPos <- min(which(critCheck))
 								
 							}else{
-								# 5.87  letzte Spalte als Position wählen 	
+								# 5.87  letzte Spalte als Position waehlen 	
 									firPos <- ncol(cauchyDF) }
 							
 						# 5.88  p-Wert entsprechend der ermittelten Position bestimmen
@@ -669,13 +670,13 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 									pValue <- paste("<=",pValue)}
 									
 					##############################################################################################################
-					### Kritische Werte für die Cauchy-Verteilung auslesen 
+					### Kritische Werte fuer die Cauchy-Verteilung auslesen 
 					############################################################################################################## 
 					
 											
 							for(i in 1:ncol(critValues)){
 								
-								# 5.90 Ist der kritische Wert für das zu spezifizierende Quantil tabelliert?
+								# 5.90 Ist der kritische Wert fuer das zu spezifizierende Quantil tabelliert?
 								if(any(names(cauchyDF) == critValues[1,i] )){
 																		
 									# 5.92 Auslesen der kritischen Werte an der Zeilen-Position des entsprechenden Stichprobenumfangs n
@@ -688,10 +689,10 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 																		
 												
 					}else{						
-						# 5.96 p-Wert kann nicht ermittelt werden, da für "n" keine tabellierten Werte existieren
+						# 5.96 p-Wert kann nicht ermittelt werden, da fuer "n" keine tabellierten Werte existieren
 							pValue <- NA
 						
-						# 5.98 kritische Werte können nicht ermittlet werden, da für "n" keine tabellierten Werte existieren
+						# 5.98 kritische Werte koennen nicht ermittlet werden, da fuer "n" keine tabellierten Werte existieren
 							critValues[2,1:ncol(critValues)] <- NA
 							cat("\n","Critical values / p-Values for the Cauchy Distribution are only tabled for sample sizes: n = 5, 8, 10, 12, 15, 20, 25, 30, 40, 50, 60, 100","\n")}
 											
@@ -699,7 +700,7 @@ pValue = sum(na.omit(simAD) > AD)/length(na.omit(simAD))
 }
 
 ###########################################################################
-####	6.00 Parameterkorrektur für die Weibull-Verteilung
+####	6.00 Parameterkorrektur fuer die Weibull-Verteilung
 ###########################################################################
 
 # 6.10 Sind die beobachteten Zufallszahlen auf Weibull-Verteilung getestet worden?
