@@ -1,10 +1,9 @@
 .NAMES = LETTERS[c(1:8, 10:26)]
-setClass(Class = "taguchiDesign", representation = representation(name = "character", factors = "list", 
-    design = "data.frame", designType = "character", replic = "data.frame", response = "data.frame", 
-    Type = "data.frame", block = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", 
-    desireVal = "list", desirability = "list", fits = "data.frame"))
-setClass("taguchiFactor", representation = representation(values = "ANY", name = "character", unit = "character", 
-    type = "character"), prototype = prototype(values = NA, name = " ", unit = " ", type = "numeric"))
+setClass(Class = "taguchiDesign", representation = representation(name = "character", factors = "list", design = "data.frame", designType = "character", 
+    replic = "data.frame", response = "data.frame", Type = "data.frame", block = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", desireVal = "list", 
+    desirability = "list", fits = "data.frame"))
+setClass("taguchiFactor", representation = representation(values = "ANY", name = "character", unit = "character", type = "character"), prototype = prototype(values = NA, 
+    name = " ", unit = " ", type = "numeric"))
 setGeneric("values", function(object) standardGeneric("values"))
 setGeneric("values<-", function(object, value) standardGeneric("values<-"))
 setMethod("values", "taguchiDesign", function(object) {
@@ -80,6 +79,7 @@ setMethod("response", "taguchiDesign", function(object) {
     return(object@response)
 })
 setReplaceMethod("response", "taguchiDesign", function(object, value) {
+#    print(deparse(substitute(value)))                                          ###
     if (!is.numeric(value) & !is.data.frame(value)) 
         stop("vector or data.frame must be given")
     if (is.numeric(value)) {
@@ -173,8 +173,7 @@ taguchiDesign = function(design, randomize = TRUE, replicates = 1) {
             odo@replic = data.frame(Replicate = odo@replic[order(RunOrder), 1])
             row.names(odo@design) = odo@design$RunOrder
             odo@runOrder = data.frame(RunOrder = data.frame(RunOrder = RunOrder)[order(RunOrder), ])
-            odo@standardOrder = data.frame(StandOrder = data.frame(StandOrder = StandOrder)[order(RunOrder), 
-                ])
+            odo@standardOrder = data.frame(StandOrder = data.frame(StandOrder = StandOrder)[order(RunOrder), ])
             odo@response = data.frame(y = rep(NA, nrow(odo@design)))
             tfList = vector("list", ncol(design))
             for (i in seq(along = tfList)) tfList[i] = new("taguchiFactor")
@@ -220,23 +219,21 @@ taguchiChoose = function(factors1 = 0, factors2 = 0, level1 = 0, level2 = 0, ia
         ss = list()
         for (i in seq(along = .oaList)) {
             li = .oaList[[i]]
-            if (li$factors1 >= factors1 & li$factors2 >= factors2 & (li$levels1 == level1 | li$levels1 == 
-                level2) & (li$levels2 == level2 | li$levels2 == level1) & li$anzahl_spalten >= Anzahl_Spalten) 
+            if (li$factors1 >= factors1 & li$factors2 >= factors2 & (li$levels1 == level1 | li$levels1 == level2) & (li$levels2 == level2 | li$levels2 == level1) & 
+                li$anzahl_spalten >= Anzahl_Spalten) 
                 ss[i] = li$id
         }
         out = as.character(ss)
         out = out[out != "NULL"]
         if (length(out) > 0) {
-            cat(paste(factors1, "factors on", level1, "levels and", factors2, "factors on", level2, 
-                "levels with", ia, "desired interactions to be estimated\n"))
+            cat(paste(factors1, "factors on", level1, "levels and", factors2, "factors on", level2, "levels with", ia, "desired interactions to be estimated\n"))
             cat("\n")
             cat("Possible Designs:\n")
             cat("\n")
             cat(paste(out, sep = " | "))
             cat("\n")
             cat("\n")
-            cat(paste("Use taguchiDesign(\"", out[1], "\") or different to create a taguchi design object\n", 
-                sep = ""))
+            cat(paste("Use taguchiDesign(\"", out[1], "\") or different to create a taguchi design object\n", sep = ""))
         }
         else {
             cat("No Design Found\n")
@@ -345,29 +342,38 @@ setMethod("identity", signature(x = "taguchiDesign"), function(x) {
         cat("\nResolution: ", as.character(as.roman(min(resolution))), "\n")
     }
     invisible(identityList)
-})
-setClass(Class = "pbDesign", representation = representation(name = "character", factors = "list", 
-    design = "data.frame", designType = "character", replic = "data.frame", response = "data.frame", 
-    Type = "data.frame", block = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", 
-    desireVal = "list", desirability = "list", fits = "data.frame"))
-setClass("pbFactor", representation = representation(values = "ANY", name = "character", unit = "character", 
-    type = "character"), prototype = prototype(values = NA, name = " ", unit = " ", type = "numeric"))
+}) 
+
+################################################################################
+#.NAMES = LETTERS[c(1:8, 10:26)]
+setClass(Class = "pbDesign", representation = representation(name = "character", factors = "list", design = "data.frame", designType = "character",
+    replic = "data.frame", response = "data.frame", Type = "data.frame", block = "data.frame", runOrder = "data.frame", standardOrder = "data.frame", desireVal = "list",
+    desirability = "list", fits = "data.frame"))
+
+setClass("pbFactor", representation = representation(values = "ANY", name = "character", unit = "character", type = "character"), prototype = prototype(values = NA,
+    name = " ", unit = " ", type = "numeric"))
+
+#setGeneric("values", function(object) standardGeneric("values"))
+#setGeneric("values<-", function(object, value) standardGeneric("values<-"))
 setMethod("values", "pbDesign", function(object) {
     listOut = vector(mode = "list")
     for (i in names(object@design)) {
         listOut[[i]] = .values(object@factors[[i]])
     }
-    return(listOut)
+   return(listOut)
 })
 setReplaceMethod("values", "pbDesign", function(object, value) {
     for (i in names(value)) {
-        if (i %in% names(object@design)) 
-            if (length(value[[i]]) == length(unique(object@design[, i]))) 
+        if (i %in% names(object@design))
+            if (length(value[[i]]) == length(unique(object@design[, i])))
                 .values(object@factors[[i]]) = value[[i]]
             else stop("Number of values greater or less than number of factor settings!")
     }
     return(object)
 })
+
+#setGeneric(".values", function(object) standardGeneric(".values"))
+#setGeneric(".values<-", function(object, value) standardGeneric(".values<-"))
 setMethod(".values", "pbFactor", function(object) object@values)
 setReplaceMethod(".values", "pbFactor", function(object, value) {
     object@values <- value
@@ -385,18 +391,19 @@ setReplaceMethod("names", "pbFactor", function(x, value) {
     x@name <- value
     x
 })
+
 setMethod("units", "pbDesign", function(x) {
     return(sapply(factors(x), .unit))
 })
 setMethod("units<-", "pbDesign", function(x, value) {
-    for (i in 1:length(x@factors)) if (length(value) > 1) 
+    for (i in 1:length(x@factors)) if (length(value) > 1)
         .unit(x@factors[[i]]) = as.character(value[i])
     else .unit(x@factors[[i]]) = as.character(value[1])
     x
 })
 setMethod("factors", "pbDesign", function(x) x@factors)
 setReplaceMethod("factors", "pbDesign", function(x, value) {
-    if (length(value) != ncol(x@design)) 
+    if (length(value) != ncol(x@design))
         stop("\nNumber of factors doesn't match with number of columns for factorial Design\n")
     x@factors <- value
     x
@@ -411,6 +418,7 @@ setReplaceMethod("names", "pbDesign", function(x, value) {
 setMethod("names", "pbFactor", function(x) {
     x@name
 })
+
 setMethod("as.data.frame", "pbDesign", function(x, row.names = NULL, optional = FALSE) {
     frameOut = cbind(x@standardOrder, x@runOrder, x@replic, x@design, x@response)
     return(frameOut)
@@ -426,17 +434,18 @@ setMethod("response", "pbDesign", function(object) {
     return(object@response)
 })
 setReplaceMethod("response", "pbDesign", function(object, value) {
-    if (!is.numeric(value) & !is.data.frame(value)) 
+#    print(deparse(substitute(value)))                                          ###
+    if (!is.numeric(value) & !is.data.frame(value))
         stop("vector or data.frame must be given")
     if (is.numeric(value)) {
-        if (length(value) != nrow(object@design)) 
+        if (length(value) != nrow(object@design))
             stop("differing lengths")
         temp = data.frame(value)
         names(temp) = deparse(substitute(value))[1]
         value = temp
     }
     if (is.data.frame(value)) {
-        if (nrow(value) != nrow(object@design)) 
+        if (nrow(value) != nrow(object@design))
             stop("differing number of rows")
     }
     object@response = value
@@ -449,7 +458,7 @@ setMethod(".nfp", "pbDesign", function(object) {
         numAttr = length(attributes(x[[1]])) - 1
         .numFac = length(x)
         len = 0
-        for (i in names(x)) if (length(x[[i]]@values) > len) 
+        for (i in names(x)) if (length(x[[i]]@values) > len)
             len = length(x[[i]]@values)
         numAttr = numAttr + len
         numrows = numAttr - 1
@@ -482,127 +491,138 @@ setMethod("summary", signature(object = "pbDesign"), function(object) {
     cat("-----------\n")
     cat("\n")
 })
-.pbDesign = function(n) {
-    k = n - 1
-    if (k == 27) {
-        X = matrix(c(+1, -1, +1, +1, +1, +1, -1, -1, -1, +1, +1, -1, +1, +1, +1, -1, -1, -1, -1, +1, 
-            +1, +1, +1, +1, -1, -1, -1, -1, -1, -1, +1, -1, +1, +1, +1, +1, -1, -1, -1, +1, +1, -1, 
-            +1, +1, +1, -1, -1, -1, -1, +1, +1, +1, +1, +1, +1, +1, +1, -1, -1, -1, +1, -1, +1, +1, 
-            +1, +1, -1, -1, -1, +1, +1, -1, +1, +1, +1, -1, -1, -1, -1, +1, +1), nrow = 9, ncol = 9, 
-            byrow = TRUE)
-        Y = matrix(c(-1, +1, -1, -1, -1, +1, -1, -1, +1, -1, -1, +1, +1, -1, -1, +1, -1, -1, +1, -1, 
-            -1, -1, +1, -1, -1, +1, -1, -1, -1, +1, -1, +1, -1, -1, -1, -1, +1, -1, -1, -1, -1, +1, 
-            +1, -1, -1, -1, +1, -1, +1, -1, -1, -1, +1, -1, -1, -1, +1, -1, -1, +1, -1, +1, -1, +1, 
-            -1, -1, +1, -1, -1, -1, -1, +1, -1, +1, -1, -1, +1, -1, +1, -1, -1), nrow = 9, ncol = 9, 
-            byrow = TRUE)
-        Z = matrix(c(+1, +1, -1, +1, -1, +1, +1, -1, +1, -1, +1, +1, +1, +1, -1, +1, +1, -1, +1, -1, 
-            +1, -1, +1, +1, -1, +1, +1, +1, -1, +1, +1, +1, -1, +1, -1, +1, +1, +1, -1, -1, +1, +1, 
-            +1, +1, -1, -1, +1, +1, +1, -1, +1, -1, +1, +1, +1, -1, +1, +1, -1, +1, +1, +1, -1, +1, 
-            +1, -1, +1, +1, -1, -1, +1, +1, -1, +1, +1, -1, +1, +1, +1, -1, +1), nrow = 9, ncol = 9, 
-            byrow = TRUE)
-        design = data.frame(rbind(cbind(X, Y, Z), cbind(X, Y, Z), cbind(X, Y, Z), rep(-1, 27)))
-    }
-    else {
-        if (k < 3) 
-            stop("k needs to be grater than three!")
-        if (k == 3) 
-            firstRow = c(+1, -1, +1)[1:k]
-        if (k > 3 && k <= 7) 
-            firstRow = c(+1, +1, +1, -1, +1, -1, -1)[1:k]
-        if (k >= 8 && k <= 11) 
-            firstRow = c(+1, +1, -1, +1, +1, +1, -1, -1, -1, +1, -1)[1:k]
-        if (k >= 12 && k <= 15) 
-            firstRow = c(+1, +1, +1, +1, -1, +1, -1, +1, +1, -1, -1, +1, -1, -1, -1)[1:k]
-        if (k >= 16 && k <= 19) 
-            firstRow = c(+1, +1, -1, -1, +1, +1, +1, +1, -1, +1, -1, +1, -1, -1, -1, -1, +1, +1, -1)[1:k]
-        if (k >= 20 && k <= 23) 
-            firstRow = c(+1, +1, +1, +1, +1, -1, +1, -1, +1, +1, -1, -1, +1, -1, -1, +1, -1, +1, -1, 
-                -1, -1, -1)[1:k]
-        if (k >= 24 && k <= 26) 
-            firstRow = c(-1, -1, -1, -1, +1, -1, +1, -1, +1, +1, +1, -1, +1, +1, -1, -1, -1, +1, +1, 
-                +1, +1, +1, -1, -1, +1, +1, -1, +1, -1, -1, +1)[1:k]
-        if (k == 27) 
-            print("insert exception here!")
-        if (k >= 29 && k <= 31) 
-            firstRow = c(-1, -1, -1, -1, +1, -1, +1, -1, +1, +1, +1, -1, +1, +1, -1, -1, -1, +1, +1, 
-                +1, +1, +1, -1, -1, +1, +1, -1, +1, -1, -1, +1)[1:k]
-        if (k >= 32 && k <= 35) 
-            firstRow = c(-1, +1, -1, +1, +1, +1, -1, -1, -1, +1, +1, +1, +1, +1, -1, +1, +1, +1, -1, 
-                -1, +1, -1, -1, -1, -1, +1, -1, +1, -1, +1, +1, -1, -1, +1, -1)[1:k]
-        if (k >= 36 && k <= 39) 
-            firstRow = c(+1, +1, -1, -1, +1, +1, +1, +1, -1, +1, -1, +1, -1, -1, -1, -1, +1, +1, -1, 
-                -1, +1, +1, -1, -1, +1, +1, +1, +1, -1, +1, -1, +1, -1, -1, -1, -1, +1, +1, -1)[1:k]
-        if (k >= 40 && k <= 43) 
-            firstRow = c(+1, +1, -1, -1, +1, -1, +1, -1, -1, +1, +1, +1, -1, +1, +1, +1, +1, +1, -1, 
-                -1, -1, +1, -1, +1, +1, +1, -1, -1, -1, -1, -1, +1, -1, -1, -1, +1, +1, -1, +1, -1, 
-                +1, +1, -1)[1:k]
-        if (k >= 44 && k <= 47) 
-            firstRow = c(+1, +1, +1, +1, +1, -1, +1, +1, +1, +1, -1, -1, +1, -1, +1, -1, +1, +1, +1, 
-                -1, -1, +1, -1, -1, +1, +1, -1, +1, +1, -1, -1, -1, +1, -1, +1, -1, +1, +1, -1, -1, 
-                -1, -1, +1, -1, -1, -1, -1)[1:k]
-        if (k >= 48 && k <= 59) 
-            firstRow = c(+1, +1, -1, +1, +1, +1, -1, +1, -1, +1, -1, -1, +1, -1, -1, +1, +1, +1, -1, 
-                +1, +1, +1, +1, -1, -1, +1, +1, +1, +1, +1, -1, -1, -1, -1, -1, +1, +1, -1, -1, -1, 
-                -1, +1, -1, -1, -1, +1, +1, -1, +1, +1, -1, +1, -1, +1, -1, -1, -1, +1, -1)[1:k]
-        design = matrix(NA, nrow = k + 1, ncol = k)
-        design[1, ] = firstRow
-        nextRow = firstRow
-        for (i in 2:k) {
-            nextRow = nextRow[c(k, 1:k - 1)]
-            design[i, ] = nextRow
-        }
-        lastRow = rep(-1, k)
-        design[k + 1, ] = lastRow
-        design = data.frame(design)
-    }
-    return(design)
+
+
+.pbDesign=function(n)
+{
+  k=n-1
+  if(k==27)
+  {
+  X=matrix(c(+1, -1, +1, +1, +1, +1, -1, -1, -1,
+             +1, +1, -1, +1, +1, +1, -1, -1, -1,
+             -1, +1, +1, +1, +1, +1, -1, -1, -1,
+             -1, -1, -1, +1, -1, +1, +1, +1, +1,
+             -1, -1, -1, +1, +1, -1, +1, +1, +1,
+             -1, -1, -1, -1, +1, +1, +1, +1, +1,
+             +1, +1, +1, -1, -1, -1, +1, -1, +1,
+             +1, +1, +1, -1, -1, -1, +1, +1, -1,
+             +1, +1, +1, -1, -1, -1, -1, +1, +1),nrow=9,ncol=9,byrow=TRUE)
+  Y=matrix(c(-1, +1, -1, -1, -1, +1, -1, -1, +1,
+             -1, -1, +1, +1, -1, -1, +1, -1, -1,
+             +1, -1, -1, -1, +1, -1, -1, +1, -1,
+             -1, -1, +1, -1, +1, -1, -1, -1, -1,
+             +1, -1, -1, -1, -1, +1, +1, -1, -1,
+             -1, +1, -1, +1, -1, -1, -1, +1, -1,
+             -1, -1, +1, -1, -1, +1, -1, +1, -1,
+             +1, -1, -1, +1, -1, -1, -1, -1, +1,
+             -1, +1, -1, -1, +1, -1, +1, -1, -1),nrow=9,ncol=9,byrow=TRUE)
+  Z=matrix(c(+1, +1, -1, +1, -1, +1, +1, -1, +1,
+             -1, +1, +1, +1, +1, -1, +1, +1, -1,
+             +1, -1, +1, -1, +1, +1, -1, +1, +1,
+             +1, -1, +1, +1, +1, -1, +1, -1, +1,
+             +1, +1, -1, -1, +1, +1, +1, +1, -1,
+             -1, +1, +1, +1, -1, +1, -1, +1, +1,
+             +1, -1, +1, +1, -1, +1, +1, +1, -1,
+             +1, +1, -1, +1, +1, -1, -1, +1, +1,
+             -1, +1, +1, -1, +1, +1, +1, -1, +1),nrow=9,ncol=9,byrow=TRUE)
+  design=data.frame(rbind(cbind(X,Y,Z),cbind(X,Y,Z),cbind(X,Y,Z),rep(-1,27)))
+  }
+  else
+  {
+   if(k<3)
+    stop("k needs to be grater than three!")
+   if(k==3)
+    firstRow=c(+1, -1, +1)[1:k]
+   if(k>3 && k<=7)
+    firstRow=c(+1, +1, +1, -1, +1, -1, -1)[1:k]
+   if(k>=8 && k<=11)
+    firstRow=c(+1, +1, -1, +1, +1, +1, -1, -1, -1, +1, -1)[1:k]
+   if(k>=12 && k<=15)
+    firstRow=c(+1, +1, +1, +1, -1, +1, -1, +1, +1, -1, -1, +1, -1, -1, -1)[1:k]
+   if(k>=16 && k<=19)
+    firstRow=c(+1, +1, -1, -1, +1, +1, +1, +1, -1, +1, -1, +1, -1, -1, -1, -1, +1, +1, -1)[1:k]
+   if(k>=20 && k<=23)
+    firstRow=c(+1, +1, +1, +1, +1, -1, +1, -1, +1, +1, -1, -1, +1, -1, -1, +1, -1, +1, -1, -1, -1, -1)[1:k]
+   if(k>=24 && k<=26)
+    firstRow=c(-1, -1, -1, -1, +1, -1, +1, -1, +1, +1, +1, -1, +1, +1, -1, -1, -1, +1, +1, +1, +1, +1, -1, -1, +1, +1, -1, +1, -1, -1, +1)[1:k]
+   if(k==27)
+    print("insert exception here!")
+   if(k>=29 && k<=31)
+    firstRow=c(-1, -1, -1, -1, +1, -1, +1, -1, +1, +1, +1, -1, +1, +1, -1, -1, -1, +1, +1, +1, +1, +1, -1, -1, +1, +1, -1, +1, -1, -1, +1)[1:k]
+   if(k>=32 && k<=35)
+    firstRow=c(-1, +1, -1, +1, +1, +1, -1, -1, -1, +1, +1, +1, +1, +1, -1, +1, +1, +1, -1, -1, +1, -1, -1, -1, -1, +1, -1, +1, -1, +1, +1, -1, -1, +1, -1)[1:k]
+   if(k>=36 && k<=39)
+    firstRow=c(+1, +1, -1, -1, +1, +1, +1, +1, -1, +1, -1, +1, -1, -1, -1, -1, +1, +1, -1, -1, +1, +1, -1, -1, +1, +1, +1, +1, -1, +1, -1, +1, -1, -1, -1, -1, +1, +1, -1)[1:k]
+   if(k>=40 && k<=43)
+    firstRow=c(+1, +1, -1, -1, +1, -1, +1, -1, -1, +1, +1, +1, -1, +1, +1, +1, +1, +1, -1, -1, -1, +1, -1, +1, +1, +1, -1, -1, -1, -1, -1, +1, -1, -1, -1, +1, +1, -1, +1, -1, +1, +1, -1)[1:k]
+   if(k>=44 && k<=47)
+    firstRow=c(+1, +1, +1, +1, +1, -1, +1, +1, +1, +1, -1, -1, +1, -1, +1, -1, +1, +1, +1, -1, -1, +1, -1, -1, +1, +1, -1, +1, +1, -1, -1, -1, +1, -1, +1, -1, +1, +1, -1, -1, -1, -1, +1, -1, -1, -1, -1)[1:k]
+   if(k>=48 && k<=59)
+    firstRow=c(+1, +1, -1, +1, +1, +1, -1, +1, -1, +1, -1, -1, +1, -1, -1, +1, +1, +1, -1, +1, +1, +1, +1, -1, -1, +1, +1, +1, +1, +1, -1, -1, -1, -1, -1, +1, +1, -1, -1, -1, -1, +1, -1, -1, -1, +1, +1, -1, +1, +1, -1, +1, -1, +1, -1, -1, -1, +1, -1)[1:k]
+
+   design=matrix(NA,nrow=k+1,ncol=k)
+   design[1,]=firstRow
+   nextRow=firstRow
+
+   for(i in 2:k)
+   {
+    nextRow=nextRow[c(k,1:k-1)]
+    design[i,]=nextRow
+   }
+   lastRow=rep(-1,k)
+   design[k+1,]=lastRow
+   design=data.frame(design)
+  }
+ return(design)
 }
-pbDesign = function(n, k, randomize = TRUE, replicates = 1) {
-    if (missing(n) && missing(k)) 
-        stop("Either n or k must be set!")
-    if (missing(n) == FALSE && missing(k) == FALSE && k != n - 1) 
-        stop("Wrong combination of n and k")
-    if (missing(n)) 
-        n = k + 1
-    if (missing(k)) 
-        k = n - 1
-    DB = FALSE
-    odo = NA
-    if (DB) 
-        print(n)
-    design = .pbDesign(n)
-    repVec = rep(1, nrow(design))
-    if (replicates > 1) {
-        X = .pbDesign(n)
-        for (i in 1:(replicates - 1)) {
-            design = rbind(design, X)
-            repVec = c(repVec, rep(i + 1, times = nrow(X)))
-        }
-    }
-    Replicate = data.frame(Replicate = as.numeric(repVec))
-    if (DB) 
-        print(Replicate)
-    odo = new("pbDesign")
-    odo@design = design
-    odo@replic = Replicate
-    StandOrder = 1:nrow(odo@design)
-    RunOrder = StandOrder
-    if (randomize) {
-        RunOrder = sample(1:nrow(odo@design), nrow(odo@design), replace = FALSE, prob = NULL)
-    }
-    odo@design = odo@design[order(RunOrder), ]
-    odo@replic = data.frame(Replicate = odo@replic[order(RunOrder), 1])
-    row.names(odo@design) = odo@design$RunOrder
-    odo@runOrder = data.frame(RunOrder = data.frame(RunOrder = RunOrder)[order(RunOrder), ])
-    odo@standardOrder = data.frame(StandOrder = data.frame(StandOrder = StandOrder)[order(RunOrder), 
-        ])
-    odo@response = data.frame(y = rep(NA, nrow(odo@design)))
-    tfList = vector("list", ncol(design))
-    for (i in seq(along = tfList)) tfList[i] = new("pbFactor")
-    names(tfList) = names(odo@design)
-    factors(odo) = tfList
-    valList = list(length = length(names(odo)))
-    for (i in names(names(odo))) valList[[i]] = sort(unique(odo@design[, i]))
-    values(odo) = valList
-    return(odo)
-} 
+
+pbDesign = function(n, k , randomize = TRUE, replicates = 1) {
+ if(missing(n)&&missing(k))
+  stop("Either n or k must be set!")
+ if(missing(n)==FALSE && missing(k)==FALSE && k!=n-1 )
+  stop("Wrong combination of n and k")
+ if(missing(n))
+  n=k+1
+ if(missing(k))
+  k=n-1  
+ DB = FALSE
+ odo = NA
+ if (DB)
+  print(n)
+ design = .pbDesign(n)
+ repVec = rep(1, nrow(design))
+ if (replicates > 1) {
+  X = .pbDesign(n)
+   for (i in 1:(replicates - 1)) {
+    design = rbind(design, X)
+    repVec = c(repVec, rep(i + 1, times = nrow(X)))
+   }
+  }
+ Replicate = data.frame(Replicate = as.numeric(repVec))
+ if (DB)
+  print(Replicate)
+  odo = new("pbDesign")
+  odo@design = design
+#  names(odo@design) = .NAMES[1:ncol(design)]
+  odo@replic = Replicate
+  StandOrder = 1:nrow(odo@design)
+  RunOrder = StandOrder
+  if (randomize) {
+   RunOrder = sample(1:nrow(odo@design), nrow(odo@design), replace = FALSE, prob = NULL)
+  }
+  odo@design = odo@design[order(RunOrder), ]
+  odo@replic = data.frame(Replicate = odo@replic[order(RunOrder), 1])
+  row.names(odo@design) = odo@design$RunOrder
+  odo@runOrder = data.frame(RunOrder = data.frame(RunOrder = RunOrder)[order(RunOrder), ])
+  odo@standardOrder = data.frame(StandOrder = data.frame(StandOrder = StandOrder)[order(RunOrder), ])
+  odo@response = data.frame(y = rep(NA, nrow(odo@design)))
+  tfList = vector("list", ncol(design))
+  for (i in seq(along = tfList)) tfList[i] = new("pbFactor")
+   names(tfList) = names(odo@design)
+  factors(odo) = tfList
+  valList = list(length = length(names(odo)))
+  for (i in names(names(odo))) valList[[i]] = sort(unique(odo@design[, i]))
+   values(odo) = valList
+ return(odo)
+}
+
